@@ -27,4 +27,10 @@ class Line:
 			elif c > 0:
 				return f'y = {m}x + {c}'
 			else:
-				return f'y = {m}x - {c*-1}'
\ No newline at end of file
+				return f'y = {m}x - {c*-1}'
+
+	def isParallel(self, l):
+		return self.gradient == l.gradient
+
+	def isPerp(self, l):
+		return self.pgrad == l.gradient
\ No newline at end of file
